pub struct PinnedAttach {
pub schema_version: u32,
pub embedding: Option<EmbeddingFingerprint>,
}Expand description
Snapshot of write-mode-relevant metadata captured by a read-only attach. Compared against the on-disk values when the reader decides whether it can still safely serve queries against the DB.
Fields
schema_version: u32embedding: Option<EmbeddingFingerprint>Trait Implementations
Sourceimpl Clone for PinnedAttach
impl Clone for PinnedAttach
Sourcefn clone(&self) -> PinnedAttach
fn clone(&self) -> PinnedAttach
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PinnedAttach
impl Debug for PinnedAttach
impl Eq for PinnedAttach
Sourceimpl PartialEq for PinnedAttach
impl PartialEq for PinnedAttach
Sourcefn eq(&self, other: &PinnedAttach) -> bool
fn eq(&self, other: &PinnedAttach) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PinnedAttach